@@ -29,6 +29,8 @@ if TYPE_CHECKING:
     import asyncio
     from ..pssm_types import ColorType
 
+
+
 NetworkDict = TypedDict("NetworkDict",
                         {"connected": bool, "wifiOn":bool, "signal": str, "MAC": Optional[str], "SSID": Optional[str]})
 
@@ -89,6 +91,8 @@ class PSSMdevice(ABC):
         self._viewHeight = viewHeight
         self._screenMode = screenMode
         self._imgMode = imgMode
+        if defaultColor == None:
+            defaultColor = "white"
         self._defaultColor = defaultColor
         
         self._name = name
@@ -297,12 +301,13 @@ class PSSMdevice(ABC):
             useFastInversion (bool): perform a fast invertion of this area.
         """
         ##This function is a leftover from the pure Eink version. Will be deprecated
-        _LOGGER.warning("This base device function is deprecated")
+        _LOGGER.debug("This base device function is deprecated")
+        # raise DeprecationWarning("This base device function is deprecated")
         pass
 
     def do_screen_clear(self):
         "Completely clear the screen"
-        _LOGGER.warning("This base device function is deprecated")
+        _LOGGER.debug("This base device function is deprecated")
 
     async def _rotate(self, rotation : RotationValues):
         """
@@ -370,7 +375,7 @@ class Network(ABC):
     def __init__(self, device : "PSSMdevice"):
         ##Should be replaced, init should call whatever methods get the ip adress etc.
         self._device = device
-        _LOGGER.trace("Setting up base device network class")
+        _LOGGER.verbose("Setting up base device network class")
 
     #region Network properties            
     @property
@@ -430,7 +435,7 @@ class Backlight(ABC):
     '''
     def __init__(self, device: "PSSMdevice", defaultBrightness : int = 50, defaultTransition : float = 0):
         ##Ensuring the backlight is off when the dashboard starts, so the brightness and state are correct
-        _LOGGER.trace("Setting up base device backlight class")
+        _LOGGER.verbose("Setting up base device backlight class")
         self._updateCondition = asyncio.Condition()
         """
         Asyncio condition that updates when the backlight changes.
